import { Boot } from './scenes/Boot';
import { Preloader } from './scenes/Preloader';


let config = {
    width: window.innerWidth, // Starting width of the canvas
    height: window.innerHeight, // Starting height of the canvas
    projectWidth: 1136, // Project width
    projectHeight: 640, // Project height
    orientation: "landscape", // Project orientation: landscape or portrait
    //backgroundColor: 0xff0000, // Pure color
    banner: false, // Hide the banner from the console
    type: Phaser.AUTO, // Render mode
    antialias: true, // Antialiasing
    disableContextMenu: true, // Disable right-click menu
    autoMobilePipeline: true, // Optimization for mobile devices
    autoRound: true, // Canvas dimensions in integers
    scene: [
        Boot,
        Preloader
    ]
}

let GAME = new Phaser.Game(config);

GAME.onResize = function () {
    const bw = window.innerWidth;
    const bh = window.innerHeight;

    const room_width = config.projectWidth;
    const room_height = config.projectHeight;

    let new_width, new_height;

    if (bw / bh > room_width / room_height) {
        new_width = room_height * bw / bh;
        new_height = room_height;
    } else {
        new_width = room_width;
        new_height = room_width * bh / bw;
    }

    this.config.width = Math.max(new_width, room_width);
    this.config.height = Math.max(new_height, room_height);

    this.scale.setZoom(bh / this.config.height);

    this.scale.resize(this.config.width, this.config.height)
    this.scale.refresh();

    //------------------------------------------------------
    this.scene.scenes.forEach(function (scene) {
        scene.children.list.forEach(function (child) {
            if (child.onResize) {
                child.onResize();
            }
        });
    });
}

window.addEventListener("resize", GAME.onResize.bind(GAME), false);

